Getting started
===============

.. contents::
   :local:


Checkout the following example to get started:

.. code-block:: console

   curl https://api.debops.org/v0/role/debops.unattended_upgrades.json -k | jq '.'

You can also open that URL in your browser via HTTP GET:
https://api.debops.org/v0/role/debops.unattended_upgrades.json

But note that the encoded JSON object is not prettified.
